@@ -15,7 +15,7 @@ from osducli.cliclient import CliOsduClient, handle_cli_exceptions
 
 # click entry point
 @click.command()
-@click.option("-id", "--id", "_id")
+@click.option("-id", "--id", "_id", help="id to search for")
 @handle_cli_exceptions
 @command_with_output(None)
 def _click_command(state: State, _id: str):
